@@ -16,21 +16,21 @@ import builtins
 import os
 
 
-def read(filename=None, input_time=None, instruments=None, insitu_only=False, specified_files_only=False):
+def read(input_time=None, instruments=None, filename=None, insitu_only=False, specified_files_only=False):
     '''
     Read in a given filename in situ file into a dictionary object
     Optional keywords maybe used to downselect instruments returned
     and the time windows.
 
     Parameters:
-        filename: str/list of str
-            Name of the in situ KP file(s) to read in.
         input_time: list of str/int
             Set a time bounds/filter on the data, must be length 2 with the first
             value being the start time, and the second value being the end time.
         instruments:
             Optional keyword listing the instruments to include 
             in the returned dictionary/structure.
+        filename: str/list of str
+            Name of the in situ KP file(s) to read in.
         insitu_only:
             Optional keyword that allows you to specify that you only want 
             to download insitu files.
